<?php

namespace BlmediaChangeStatusByPrice;

use Shopware\Components\Console\Application;
use Shopware\Components\Plugin\Context\ActivateContext;
use Shopware\Components\Plugin\Context\DeactivateContext;
use Shopware\Components\Plugin\Context\InstallContext;
use Shopware\Components\Plugin\Context\UpdateContext;
use Shopware\Components\Plugin\Context\UninstallContext;
use Shopware\Bundle\AttributeBundle\Service\CrudService;
use Symfony\Component\Console\Input\StringInput;

/**
 * Class BlmediaChangeStatusByPrice
 *
 * @package BlmediaChangeStatusByPrice
 */
class BlmediaChangeStatusByPrice extends \Shopware\Components\Plugin
{
    /**
     * clearCache setting
     * @var array
     */
    private $clearCache = InstallContext::CACHE_LIST_ALL;


    /**
     * register cli commands
     *
     * @param Application $application
     */
    public function registerCommands(Application $application)
    {
        $application->add(new BlmediaChangeStatusByPriceCommand());
    }

    /**
     * register cronjob
     *
     * @return array
     */
    public static function getSubscribedEvents()
    {
        return [
            'Shopware_CronJob_Check_Order_Price' => 'onCheckPrice'
        ];
    }

    /**
     * @param \Shopware_Components_Cron_CronJob $job
     * @return string
     */
    public function onCheckPrice(\Shopware_Components_Cron_CronJob $job)
    {
        $command = new BlmediaChangeStatusByPriceCommand();
        $command->setContainer(Shopware()->Container());
        $input = new \Symfony\Component\Console\Input\StringInput('');
        $output = new \Symfony\Component\Console\Output\BufferedOutput();
        $command->run($input, $output);
        return($output->fetch());
    }

    /** ============= Install / Uninstall ============ */

    /**
     * overrides the install method
     *
     * @param InstallContext $context
     * @return array
     */
    public function install(InstallContext $context)
    {
        $this->checkSystem();
        $this->createAttributes();

        return [
            'success' => true
        ];
    }

    /**
     * overrides the update method
     *
     * @param UpdateContext $context
     * @return array
     */
    public function update(UpdateContext $context)
    {
        $context->scheduleClearCache($this->clearCache);

        return [
            'success' => true
        ];
    }

    /**
     * overrides the activate method
     *
     * @param ActivateContext $context
     * @return array
     */
    public function activate(ActivateContext $context)
    {
        // $this->translate();
        $context->scheduleClearCache($this->clearCache);
        $this->changeActiveState('1');

        return [
            'success' => true
        ];
    }

    /**
     * overrides the deactivate method
     *
     * @param DeactivateContext $context
     * @return array
     */
    public function deactivate(DeactivateContext $context)
    {
        $context->scheduleClearCache($this->clearCache);
        $this->changeActiveState('0');

        return [
            'success' => true
        ];
    }

    /**
     * overrides the uninstall method
     *
     * @param UninstallContext $context
     * @return array
     */
    public function uninstall(UninstallContext $context)
    {
        $this->deleteAttributes();
        $this->changeActiveState('0');

        $context->scheduleClearCache($this->clearCache);

        return [
            'success' => true
        ];
    }

    private function changeActiveState($stateID)
    {
        $path = __DIR__ . '/pluginActive.txt';

        $pluginActiveFile = fopen($path, "w+");
        if(!$pluginActiveFile)
            throw new \Exception('Unable to open file: ' . $path);
        fwrite($pluginActiveFile, $stateID);
        fclose($pluginActiveFile);
        return true;
    }

    /**
     * Checks the system (PHP version, MySQL version, ...).
     *
     * @throws \Exception
     */
    private function checkSystem()
    {
        // PHP version
        if(!version_compare(PHP_VERSION, '5.6.0', '>='))
            throw new \Exception('To install the plugin you need PHP version 5.0 or higher.');

        // MySQL version
        if(!version_compare(Shopware()->Db()->getServerVersion(), '5.0', '>='))
            throw new \Exception('To install the plugin you need MySQL version 5.0 or higher.');
    }


    /** ============= Database structure ============= */

    /**
     * Creates the needed attributes in the table s_categories_attributes
     */
    private function createAttributes() {

    }

    /**
     * Deletes the created attributes from the table s_categories_attributes
     */
    private function deleteAttributes() {

    }


}