<?php


namespace BlmediaChangeStatusByPrice;

use Doctrine\DBAL\Connection;
use Shopware\Commands\ShopwareCommand;
use Symfony\Component\Console\Input\InputInterface;
use Symfony\Component\Console\Output\OutputInterface;

/**
 * Class BlmediaChangeStatusByPriceCommand
 * @package BlmediaChangeStatusByPrice
 */
class BlmediaChangeStatusByPriceCommand extends ShopwareCommand
{
    protected function configure()
    {
        return $this->setName('blmedia:change-status-by-price')
            ->setDescription('Change payment status by price')
            ->setHelp(<<<EOF
The <info>%command.name%</info> checks all orders with configured order status for payment status change by order sum.
EOF
            );
    }

    /**
     * fetch unprocessed orders from database
     * check for search string in field specified by plugin configuration
     * change dispatch if necessary
     *
     * @param InputInterface $input
     * @param OutputInterface $output
     */
    protected function execute(InputInterface $input, OutputInterface $output)
    {
        $container = Shopware()->Container();

        // prepare database usage
        /** @var \Doctrine\DBAL\Connection $connection */
        $connection = $container->get('dbal_connection');

        // fetch configuration
        /** @var \Shopware_Components_Config $config */
        $config = $container->get('shopware.plugin.cached_config_reader')->getByPluginName('BlmediaChangeStatusByPrice');

        /** @var \Shopware\Bundle\SearchBundleDBAL\QueryBuilder $queryBuilder */
        $queryBuilder = $connection->createQueryBuilder();

        $output->writeln(print_r($config['blmedia_statusbyprice_order_status'],true));
        $output->writeln(print_r($config['blmedia_statusbyprice_operator'],true));


        $queryBuilder->select('o.id', 'o.ordernumber', 'o.invoice_amount')
            ->from('s_order', 'o')
            ->where('o.status IN (' . implode(',',$config['blmedia_statusbyprice_order_status']) . ')')
            ->andWhere('o.cleared <> ' . $config['blmedia_statusbyprice_payment_status'] )
            ->andWhere('o.invoice_amount '
                . $config['blmedia_statusbyprice_operator']
                . ' ' . $config['blmedia_statusbyprice_price']);

        $orders = $queryBuilder->execute()->fetchAll();

        if(!empty($orders)) {

            $in = [];
            $count = 0;
            $changed = [];

            foreach($orders as $order){
                $in[] = $order['id'];
                $count++;
                $changed[$order['ordernumber']] = $order['invoice_amount'];
            }

            $queryBuilder = $connection->createQueryBuilder();
            $queryBuilder->update('s_order', 'o')
                ->set('o.cleared', ':ps')
                ->where('o.id IN (:oids)')
                ->setParameter('ps', $config['blmedia_statusbyprice_payment_status'])
                ->setParameter('oids', $in, Connection::PARAM_STR_ARRAY);

            $queryBuilder->execute();

            // output with some debug information
            $output->writeln('Successfully processed ' . $count . ' order(s).');
            if ($output->isVerbose()) {
                $output->writeln('Changed payment status for orders: ');
                foreach($changed as $nr=>$amount) {
                    $output->writeln(' - order ' . $nr . ' with sum ' . $amount);
                }
            }
        }

        // no orders found
        else{
            $output->writeln('Successfully processed - no orders found');
        }
    }
}